==> 0.7.1.zip: grichelde/localisation/enUS.lua <==
local L = LibStub('AceLocale-3.0'):NewLocale('Grichelde', 'enUS', true)
if not L then return end

-- system messages
L.AddonName = "Grichelde"
L.VersionAbbr = "v"
L.AddonLoaded = "%s now helps you with your spelling disabilities."
L.Upgrade_ToVersion = "Upgrade database to version %s."
L.Upgrade_Successful = "Upgrade successful."
L.Debug_Options = "Options"
L.Debug_Mappings = "Mappings"
L.Debug_Mappings_Found = "%d Mappings found"

-- profiles
L.Profiles_Available = "Available profiles:"
L.Profiles_Created = "New profile %s created."
L.Profiles_Loaded = "Profile %s is loaded."
L.Profiles_Refreshed = "Profil %s refreshed."
L.Profiles_Deleted = "Profile %s deleted."
L.Profiles_Copied = "Settings applied from profile %s."
L.Profiles_Reset = "Profil %s reset."
L.Profiles_Invalid = "Invalid profile %s!"
L.Profiles_DeleteError = "The active profile cannot be deleted!"

-- options
L.Options_Title = "%s Options"
L.Options_Enabled_Name = "Enabled"
L.Options_Enabled_Desc = "Enables %s"

L.Options_Channels_Group_Name = "Channels"
L.Options_Channels_Group_Desc = "%s is active in the following channels."
L.Options_Channels_Header = "Text replacement will only be done for marked channels below:"

L.Options_Channel_Say_Name = "Say"
L.Options_Channel_Say_Desc = "Activates %s in channel \"Say\"."
L.Options_Channel_Emote_Name = "Emote"
L.Options_Channel_Emote_Desc = "Activates %s in channel \"Emote\"."
L.Options_Channel_Yell_Name = "Yell"
L.Options_Channel_Yell_Desc = "Activates %s in channel \"Yell\"."
L.Options_Channel_Party_Name = "Party"
L.Options_Channel_Party_Desc = "Activates %s in channel \"Party\"."
L.Options_Channel_PartyLeader_Name = "Party Leader"
L.Options_Channel_PartyLeader_Desc = "Activates %s in channel \"Party Leader\"."
L.Options_Channel_Guild_Name = "Guild"
L.Options_Channel_Guild_Desc = "Activates %s in channel \"Guild\"."
L.Options_Channel_Officer_Name = "Officers"
L.Options_Channel_Officer_Desc = "Activates %s in channel \"Officers\"."
L.Options_Channel_Raid_Name = "Raid"
L.Options_Channel_Raid_Desc = "Activates %s in channel \"Raid\"."
L.Options_Channel_RaidLeader_Name = "Raid Leader"
L.Options_Channel_RaidLeader_Desc = "Activates %s in channel \"Raid Leader\"."
L.Options_Channel_RaidWarning_Name = "Raid Warning"
L.Options_Channel_RaidWarning_Desc = "Activates %s in channel \"Raid Warning\"."
L.Options_Channel_Instance_Name = "Instance"
L.Options_Channel_Instance_Desc = "Activates %s in channel \"Instance\"."
L.Options_Channel_Battleground_Name = "Battleground"
L.Options_Channel_Battleground_Desc = "Activates %s in channel \"Battleground\"."
L.Options_Channel_Whisper_Name = "Whisper"
L.Options_Channel_Whisper_Desc = "Activates %s in channel \"Whisper\"."

L.Options_Replacements_Group_Name = "Replacements"
L.Options_Replacements_Group_Desc = "These lookups will be replaced in activated channels."
L.Options_Replacements_Add_Name = "Add"
L.Options_Replacements_Add_Desc = "Adds a new replacement mapping."
L.Options_Replacements_DeleteAll_Name = "Delete All"
L.Options_Replacements_DeleteAll_Desc = "Deletes all replacement mappings."
L.Options_Replacements_DeleteAll_ConfirmText = "Do you really want to delete ALL replacement mappings?"
L.Options_Replacements_Header = "All matches on the lefthand side of the arrow ( => ) will be replaced in activated channels by the text on the righthand side."
                                .. "|nIf case sensivity is ignored, the case for each letter of the matching text is taken over when replaced."
                                .. "|nConsolidation of consecutive matches prevent unaesthetic repetitions of letters introduced by replacements."
                                .. "|nWith both default mappings active, the mapping would be \"Tossing\" => \"Ckoching\"."
L.Options_Mapping_Group_Name = "%s => %s"
L.Options_Mapping_Group_Desc = "This lookup will be replaced in activated channels."
L.Options_Mapping_EmptyMapping = "(none)"
L.Options_Mapping_SearchText_Name = "Search for:"
L.Options_Mapping_SearchText_Desc = "This text is looked up in your chat input box."
L.Options_Mapping_ReplaceText_Name = "Replacement:"
L.Options_Mapping_ReplaceText_Desc = "Any match will be replaced with this text."
L.Options_Mapping_ExactCase_Name = "exact case"
L.Options_Mapping_ExactCase_Desc = "When set, matches must be case-sensitive. Otherwise the case for each letter of the matching text is taken over when replaced."
L.Options_Mapping_Consolidate_Name = "consolidate consecutive matches"
L.Options_Mapping_Consolidate_Desc = "If after the replacement a text sequence is repeated|ndirectly after another, treat them as one occurrence."
L.Options_Mapping_MoveUp_Name = "^"
L.Options_Mapping_MoveUp_Desc = "move up"
L.Options_Mapping_MoveDown_Name = "v"
L.Options_Mapping_MoveDown_Desc = "move down"
L.Options_Mapping_Delete_Name = "Delete"
L.Options_Mapping_Delete_Desc = "Deletes this replacement mapping."
L.Options_Mapping_Delete_ConfirmText = "Delete this replacement mapping?"

==> 0.7.2.zip: grichelde/localisation/enUS.lua <==
local L = LibStub('AceLocale-3.0'):NewLocale('Grichelde', 'enUS', true)
if not L then return end

-- system messages
L.AddonName = "Grichelde"
L.VersionAbbr = "v"
L.AddonLoaded = "%s now helps you with your spelling disabilities."
L.Upgrade_ToVersion = "Upgrade database to version %s."
L.Upgrade_Successful = "Upgrade successful."
-- debug
L.Debug_Options = "Options"
L.Debug_Mappings = "Mappings"
L.Debug_Mappings_Hint = "The content of this input box is used for debugging purposes only and can be copied. No input from this box will be read or processed."
L.Debug_Mappings_Found = "%d mappings found"
L.Debug_Profile = "Profile"

-- profiles
L.Profiles_Available = "Available profiles:"
L.Profiles_Created = "New profile %s created."
L.Profiles_Loaded = "Profile %s is loaded."
L.Profiles_Refreshed = "Profil %s refreshed."
L.Profiles_Deleted = "Profile %s deleted."
L.Profiles_Copied = "Settings applied from profile %s."
L.Profiles_Reset = "Profil %s reset."
L.Profiles_Invalid = "Invalid profile %s!"
L.Profiles_DeleteError = "The active profile cannot be deleted!"

-- options
L.Options_Title = "%s Options"
L.Options_Enabled_Name = "Enabled"
L.Options_Enabled_Desc = "Enables %s"
L.Options_Minimap_Button_Name = "Show minimap button"
L.Options_Minimap_Button_Desc = "Shows or hides the button on the minimap."
L.Options_Minimap_Tooltip_Options_Left = "Left-Click"
L.Options_Minimap_Tooltip_Options_Right = "Opens or closes the options UI."
L.Options_Minimap_Tooltip_Mappings_Left = "Right-Click"
L.Options_Minimap_Tooltip_Mappings_Right = "Opens the debug window with mapping code."


L.Options_Channels_Group_Name = "Channels"
L.Options_Channels_Group_Desc = "%s is active in the following channels."
L.Options_Channels_Header = "Text replacement will only be done for marked channels below:"

L.Options_Channel_Say_Name = "Say"
L.Options_Channel_Say_Desc = "Activates %s in channel \"Say\"."
L.Options_Channel_Emote_Name = "Emote"
L.Options_Channel_Emote_Desc = "Activates %s in channel \"Emote\"."
L.Options_Channel_Yell_Name = "Yell"
L.Options_Channel_Yell_Desc = "Activates %s in channel \"Yell\"."
L.Options_Channel_Party_Name = "Party"
L.Options_Channel_Party_Desc = "Activates %s in channel \"Party\"."
L.Options_Channel_PartyLeader_Name = "Party Leader"
L.Options_Channel_PartyLeader_Desc = "Activates %s in channel \"Party Leader\"."
L.Options_Channel_Guild_Name = "Guild"
L.Options_Channel_Guild_Desc = "Activates %s in channel \"Guild\"."
L.Options_Channel_Officer_Name = "Officers"
L.Options_Channel_Officer_Desc = "Activates %s in channel \"Officers\"."
L.Options_Channel_Raid_Name = "Raid"
L.Options_Channel_Raid_Desc = "Activates %s in channel \"Raid\"."
L.Options_Channel_RaidLeader_Name = "Raid Leader"
L.Options_Channel_RaidLeader_Desc = "Activates %s in channel \"Raid Leader\"."
L.Options_Channel_RaidWarning_Name = "Raid Warning"
L.Options_Channel_RaidWarning_Desc = "Activates %s in channel \"Raid Warning\"."
L.Options_Channel_Instance_Name = "Instance"
L.Options_Channel_Instance_Desc = "Activates %s in channel \"Instance\"."
L.Options_Channel_Battleground_Name = "Battleground"
L.Options_Channel_Battleground_Desc = "Activates %s in channel \"Battleground\"."
L.Options_Channel_Whisper_Name = "Whisper"
L.Options_Channel_Whisper_Desc = "Activates %s in channel \"Whisper\"."

L.Options_Replacements_Group_Name = "Replacements"
L.Options_Replacements_Group_Desc = "These lookups will be replaced in activated channels."
L.Options_Replacements_Add_Name = "Add"
L.Options_Replacements_Add_Desc = "Adds a new replacement mapping."
L.Options_Replacements_DeleteAll_Name = "Delete All"
L.Options_Replacements_DeleteAll_Desc = "Deletes all replacement mappings."
L.Options_Replacements_DeleteAll_ConfirmText = "Do you really want to delete ALL replacement mappings?"
L.Options_Replacements_Header = "All matches on the lefthand side of the arrow ( => ) will be replaced in activated channels by the text on the righthand side."
                                .. "|nIf case sensivity is ignored, the case for each letter of the matching text is taken over when replaced."
                                .. "|nConsolidation of consecutive matches prevent unaesthetic repetitions of letters introduced by replacements."
                                .. "|nWith both default mappings active, the mapping would be \"Tossing\" => \"Ckoching\"."
L.Options_Mapping_Group_Name = "%s => %s"
L.Options_Mapping_Group_Desc = "This lookup will be replaced in activated channels."
L.Options_Mapping_EmptyMapping = "(none)"
L.Options_Mapping_SearchText_Name = "Search for:"
L.Options_Mapping_SearchText_Desc = "This text is looked up in your chat input box."
L.Options_Mapping_ReplaceText_Name = "Replacement:"
L.Options_Mapping_ReplaceText_Desc = "Any match will be replaced with this text."
L.Options_Mapping_ExactCase_Name = "exact case"
L.Options_Mapping_ExactCase_Desc = "When set, matches must be case-sensitive. Otherwise the case for each letter of the matching text is taken over when replaced."
L.Options_Mapping_Consolidate_Name = "consolidate consecutive matches"
L.Options_Mapping_Consolidate_Desc = "If after the replacement a text sequence is repeated|ndirectly after another, treat them as one occurrence."
L.Options_Mapping_MoveUp_Name = "^"
L.Options_Mapping_MoveUp_Desc = "move up"
L.Options_Mapping_MoveDown_Name = "v"
L.Options_Mapping_MoveDown_Desc = "move down"
L.Options_Mapping_Delete_Name = "Delete"
L.Options_Mapping_Delete_Desc = "Deletes this replacement mapping."
L.Options_Mapping_Delete_ConfirmText = "Delete this replacement mapping?"
